acImageFactoryConvertBayerAlgorithm

Function acImageFactoryConvertBayerAlgorithm 

pub unsafe extern "C" fn acImageFactoryConvertBayerAlgorithm(
    hSrc: acBuffer,
    pixelFormat: u64,
    bayerAlgo: AC_BAYER_ALGORITHM,
    phDst: *mut acBuffer,
) -> AC_ERROR
@fn AC_ERROR AC_API acImageFactoryConvertBayerAlgorithm(acBuffer hSrc, uint64_t pixelFormat, AC_BAYER_ALGORITHM bayerAlgo, acBuffer* phDst)

@param hSrc

  • Type: acBuffer
  • [In] parameter
  • Image to convert

@param pixelFormat

  • Type: uint64_t
  • [In] parameter
  • Pixel format to convert to

@param bayerAlgo

  • Type: AC_BAYER_ALGORITHM
  • [In] parameter
  • Bayer conversion algorithm to use
  • Only applicable when converting from bayer

@param phDst

  • Type: acBuffer*
  • [Out] parameter
  • Converted image

@return

  • Type: AC_ERROR
  • Error code for the function
  • Returns AC_ERR_SUCCESS (0) on success

acImageFactoryConvert converts an image (acBuffer) to a select pixel format. In doing so, it creates a completely new image, similar to a deep copy but with a different pixel format. Images created with the image factory must be destroyed (acImageFactoryDestroy) when no longer needed; otherwise, memory will leak.

@see

  • acBuffer
  • acImageFactoryDestroy